==> eiffelstudio-18.11.10.2592.tar: F_code/C6/xm288.c <==
/*
 * Code for class XM_EIFFEL_CHARACTER_ENTITY
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "xm288.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {XM_EIFFEL_CHARACTER_ENTITY}.make */
void F934_5977 (EIF_REFERENCE Current)
{
	GTCX
	
	
	RTGC;
}

/* {XM_EIFFEL_CHARACTER_ENTITY}.from_decimal */
void F934_5978 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_INTEGER_32 ti4_1;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLIU(2);
	
	RTGC;
	ti4_1 = F909_5470(RTCW(arg1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_0_) = (EIF_INTEGER_32) ti4_1;
	RTLE;
}

/* {XM_EIFFEL_CHARACTER_ENTITY}.from_hexadecimal */
void F934_5979 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLIU(3);
	
	RTGC;
	tr1 = RTOSCF(5976,F933_5976,(Current));
	ti4_1 = F922_5934(RTCW(tr1), arg1);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_0_) = (EIF_INTEGER_32) ti4_1;
	RTLE;
}

/* {XM_EIFFEL_CHARACTER_ENTITY}.is_valid */
EIF_BOOLEAN F934_5982 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_INTEGER_32 ti4_3;
	EIF_INTEGER_32 ti4_4;
	EIF_INTEGER_32 ti4_5;
	EIF_INTEGER_32 ti4_6;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	tr1 = RTOSCF(3008,F351_3008,(Current));
	tb1 = F1222_8747(RTCW(tr1), *(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_0_));
	if (tb1) {
		ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_0_);
		ti4_2 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_0_);
		ti4_3 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_0_);
		ti4_4 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_0_);
		ti4_5 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_0_);
		ti4_6 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_0_);
		Result = (EIF_BOOLEAN) (EIF_BOOLEAN) ((EIF_BOOLEAN) ((EIF_BOOLEAN) ((EIF_BOOLEAN)(ti4_1 == ((EIF_INTEGER_32) 9L)) || (EIF_BOOLEAN)(ti4_2 == ((EIF_INTEGER_32) 10L))) || (EIF_BOOLEAN)(ti4_3 == ((EIF_INTEGER_32) 13L))) || ((EIF_BOOLEAN) ((EIF_BOOLEAN) ((EIF_BOOLEAN) (ti4_4 >= ((EIF_INTEGER_32) 32L)) && (EIF_BOOLEAN)(ti4_5 != ((EIF_INTEGER_32) 65279L))) && (EIF_BOOLEAN)(ti4_6 != ((EIF_INTEGER_32) 65535L)))));
	}
	RTLE;
	return Result;
}

/* {XM_EIFFEL_CHARACTER_ENTITY}.is_ascii */
EIF_BOOLEAN F934_5983 (EIF_REFERENCE Current)
{
	GTCX
	
	
	return (EIF_BOOLEAN) (EIF_BOOLEAN) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_0_) <= ((EIF_INTEGER_32) 127L));
}

/* {XM_EIFFEL_CHARACTER_ENTITY}.to_utf8 */
EIF_REFERENCE F934_5985 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,tr1);
	RTLR(1,Result);
	RTLR(2,Current);
	RTLIU(3);
	
	RTGC;
	tr1 = RTLNS(eif_new_type(916, 0x00).id, 916, _OBJSIZ_1_1_0_3_0_0_0_0_);
	F913_5574(RTCW(tr1), ((EIF_INTEGER_32) 6L));
	Result = (EIF_REFERENCE) tr1;
	tr1 = RTOSCF(2505,F269_2505,(Current));
	ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_0_);
	F936_6009(RTCW(tr1), Result, ti4_1);
	RTLE;
	return Result;
}

void EIF_Minit288 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C6/xm288.c <==
/*
 * Code for class XM_EIFFEL_CHARACTER_ENTITY
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "xm288.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {XM_EIFFEL_CHARACTER_ENTITY}.make */
void F934_6002 (EIF_REFERENCE Current)
{
	GTCX
	
	
	RTGC;
}

/* {XM_EIFFEL_CHARACTER_ENTITY}.from_decimal */
void F934_6003 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_INTEGER_32 ti4_1;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLIU(2);
	
	RTGC;
	ti4_1 = F909_5495(RTCW(arg1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_0_) = (EIF_INTEGER_32) ti4_1;
	RTLE;
}

/* {XM_EIFFEL_CHARACTER_ENTITY}.from_hexadecimal */
void F934_6004 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLIU(3);
	
	RTGC;
	tr1 = RTOSCF(6001,F933_6001, (Current));
	ti4_1 = F922_5959(RTCW(tr1), arg1);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_0_) = (EIF_INTEGER_32) ti4_1;
	RTLE;
}

/* {XM_EIFFEL_CHARACTER_ENTITY}.is_valid */
EIF_BOOLEAN F934_6007 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_INTEGER_32 ti4_3;
	EIF_INTEGER_32 ti4_4;
	EIF_INTEGER_32 ti4_5;
	EIF_INTEGER_32 ti4_6;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	tr1 = RTOSCF(2965,F349_2965, (Current));
	tb1 = F1228_8782(RTCW(tr1), *(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_0_));
	if (tb1) {
		ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_0_);
		ti4_2 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_0_);
		ti4_3 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_0_);
		ti4_4 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_0_);
		ti4_5 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_0_);
		ti4_6 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_0_);
		Result = (EIF_BOOLEAN) (EIF_BOOLEAN) ((EIF_BOOLEAN) ((EIF_BOOLEAN) ((EIF_BOOLEAN)(ti4_1 == ((EIF_INTEGER_32) 9L)) || (EIF_BOOLEAN)(ti4_2 == ((EIF_INTEGER_32) 10L))) || (EIF_BOOLEAN)(ti4_3 == ((EIF_INTEGER_32) 13L))) || ((EIF_BOOLEAN) ((EIF_BOOLEAN) ((EIF_BOOLEAN) (ti4_4 >= ((EIF_INTEGER_32) 32L)) && (EIF_BOOLEAN)(ti4_5 != ((EIF_INTEGER_32) 65279L))) && (EIF_BOOLEAN)(ti4_6 != ((EIF_INTEGER_32) 65535L)))));
	}
	RTLE;
	return Result;
}

/* {XM_EIFFEL_CHARACTER_ENTITY}.is_ascii */
EIF_BOOLEAN F934_6008 (EIF_REFERENCE Current)
{
	GTCX
	
	
	return (EIF_BOOLEAN) (EIF_BOOLEAN) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_0_) <= ((EIF_INTEGER_32) 127L));
}

/* {XM_EIFFEL_CHARACTER_ENTITY}.to_utf8 */
EIF_REFERENCE F934_6010 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,Result);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTGC;
	Result = RTLNS(eif_new_type(916, 0x01).id, 916, _OBJSIZ_1_1_0_3_0_0_0_0_);
	F915_5724(RTCW(Result), ((EIF_INTEGER_32) 6L));
	tr1 = RTOSCF(2508,F268_2508, (Current));
	F935_6024(RTCW(tr1), Result, *(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_0_));
	RTLE;
	return Result;
}

void EIF_Minit288 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
